@@ -168,6 +168,8 @@ class AtlasEventTypes(Enum):
     DATA_EXPLORER_CRUD = 'Data Explorer Crud'
     DATA_EXPLORER_CRUD_ERROR = 'Data Explorer Crud Error'
     DATA_EXPLORER_CRUD_ATTEMPT = 'Data Explorer Crud Attempt'
+    DATA_FEDERATION_QUERY_LIMIT_CONFIGURED = 'Data Federation Query Limit configured'
+    DATA_FEDERATION_QUERY_LIMIT_DELETED = 'Data Federation Query Limit deleted'
     AWS_ENCRYPTION_KEY_ROTATED = 'AWS Encryption Key Rotated'
     AWS_ENCRYPTION_KEY_NEEDS_ROTATION = 'AWS Encryption Key Needs Rotation'
     AZURE_ENCRYPTION_KEY_ROTATED = 'Azure Encryption Key Rotated'
@@ -338,6 +340,14 @@ class AtlasEventTypes(Enum):
     ATLAS_MAINTENANCE_AUTO_DEFER_DISABLED = 'Atlas Maintenance Auto Defer Disabled'
     ATLAS_MAINTENANCE_START_ASAP = 'Atlas Maintenance Start Asap'
     ATLAS_MAINTENANCE_SCHEDULED_FOR_NEXT_WINDOW = 'Atlas Maintenance Scheduled For Next Window'
+    MAINTENANCE_WINDOW_ADDED = 'Atlas Maintenance Window Added'
+    MAINTENANCE_WINDOW_MODIFIED = 'Atlas Maintenance Window Modified'
+    MAINTENANCE_WINDOW_REMOVED = 'Atlas Maintenance Window Removed'
+    MAINTENANCE_DEFERRED = 'Atlas Maintenance Deferred'
+    MAINTENANCE_AUTO_DEFER_ENABLED = 'Atlas Maintenance Auto Defer Enabled'
+    MAINTENANCE_AUTO_DEFER_DISABLED = 'Atlas Maintenance Auto Defer Disabled'
+    MAINTENANCE_START_ASAP = 'Atlas Maintenance Start Asap'
+    MAINTENANCE_SCHEDULED_FOR_NEXT_WINDOW = 'Atlas Maintenance Scheduled For Next Window'
     COMPUTE_AUTO_SCALE_UNNECESSARY = 'Compute Auto Scale Unnecessary'
     COMPUTE_AUTO_SCALE_TRIGGERED = 'Compute Auto Scale Triggered'
     COMPUTE_AUTO_SCALE_SKIPPED = 'Compute Auto Scale Skipped'
